/* 
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.pdfextractor.structure;

import java.util.ArrayList;
import java.util.Objects;

/**
 * This represents a parsed document which is defined as a sequence of pages.
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class Document extends LineSegment {

	public final ArrayList<Page> content = new ArrayList<>();

	public Document() {
	}

	@Override
	public int hashCode() {
		int hash = 7;
		hash = 83 * hash + Objects.hashCode(this.content);
		return hash;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		final Document other = (Document) obj;
		if (!Objects.equals(this.content, other.content)) {
			return false;
		}
		return true;
	}

	@Override
	public String toString() {
		final StringBuilder output = new StringBuilder();
		for (int i = 0; i < content.size(); i++) {
			output.append(content.get(i).toString());
			if (i < content.size() - 1) {
				output.append("\n\n\n");
			}
		}
		return output.toString();
	}

	/**
	 * Does the same as toString but also inserts the beginning and end index of each objects
	 * respective text representation.
	 */
	public String indexedToString(int currentIdx) {
		setBegin(currentIdx);
		final StringBuilder output = new StringBuilder();
		for (int i = 0; i < content.size(); i++) {
			final String pageStr = content.get(i).indexedToString(currentIdx);
			output.append(pageStr);
			currentIdx += pageStr.length();
			if (i < content.size() - 1) {
				output.append("\n\n\n");
				currentIdx += 3;
			}
		}
		setEnd(currentIdx);
		return output.toString();
	}

	public String toXML() {
		final StringBuilder output = new StringBuilder();
		output.append("<Document>\n");
		for (int i = 0; i < content.size(); i++) {
			output.append(content.get(i).toXML());
			if (i < content.size() - 1) {
				output.append("\n");
			}
		}
		output.append("\n</Document>");
		return output.toString();
	}
}
