/* 
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.pdfextractor.structure;

import java.util.ArrayList;
import java.util.Objects;

/**
 * This represents a paragraph of text that is defined as a sequence of Text objects that
 * syntactically were grouped in a paragraph.
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class Paragraph extends LineSegment {

	/**
	 * This is the Text content of this Paragraph.
	 */
	public final ArrayList<Text> content = new ArrayList<>();

	public Paragraph() {
	}

	@Override
	public int hashCode() {
		int hash = 5;
		hash = 61 * hash + Objects.hashCode(this.content);
		return hash;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		final Paragraph other = (Paragraph) obj;
		if (!Objects.equals(this.content, other.content)) {
			return false;
		}
		return true;
	}

	@Override
	public String toString() {
		final StringBuilder output = new StringBuilder();
		for (int i = 0; i < content.size(); i++) {
			output.append(content.get(i).toString());
			if (i < content.size() - 1) {
				output.append(' ');
			}
		}
		return output.toString();
	}

	/**
	 * Does the same as toString but also inserts the beginning and end index of each objects
	 * respective text representation.
	 */
	public String indexedToString(int currentIdx) {
		setBegin(currentIdx);
		final StringBuilder output = new StringBuilder();
		for (int i = 0; i < content.size(); i++) {
			final String textStr = content.get(i).indexedToString(currentIdx);
			output.append(textStr);
			currentIdx += textStr.length();
			if (i < content.size() - 1) {
				output.append(' ');
				currentIdx++;
			}
		}
		setEnd(currentIdx);
		return output.toString();
	}

	public String toXML() {
		final StringBuilder output = new StringBuilder();
		output.append("\t\t\t<Paragraph>\n");
		for (int i = 0; i < content.size(); i++) {
			output.append(content.get(i).toXML());
			if (i < content.size() - 1) {
				output.append("\n");
			}
		}
		output.append("\n\t\t\t</Paragraph>");
		return output.toString();
	}
}
